@@ -362,7 +362,7 @@ class NodeEnrollCommand(BaseCommand):
             patch = self._to_ironic_patch(node_params)
             self.log.debug(f'Ironic node patch for {node.uuid}: {patch}')
             ironic.node.update(node.uuid, patch)
-            self.log.info(f'Update Ironic node {node.uuid} ({node_name})')
+            self.log.info(f'Updated Ironic node {node.uuid} ({node_name})')
         except HTTPNotFound:
             node_params['name'] = node_name
             self.log.debug(f'Ironic node create: {node_params}')
@@ -462,4 +462,6 @@ class NodeEnrollCommand(BaseCommand):
             ironic.node.set_provision_state(node.uuid, 'provide')
             ironic.node.wait_for_provision_state(node.uuid, 'available')
 
+        ironic.node.set_console_mode(node.uuid, True)
+
         self._ensure_blazar_host(blazar, node, blazar_hosts)
